summaryrefslogtreecommitdiffstats
path: root/kxkb/kxkbtraywindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'kxkb/kxkbtraywindow.h')
-rw-r--r--kxkb/kxkbtraywindow.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kxkb/kxkbtraywindow.h b/kxkb/kxkbtraywindow.h
index 089a7906b..66d1c7220 100644
--- a/kxkb/kxkbtraywindow.h
+++ b/kxkb/kxkbtraywindow.h
@@ -24,7 +24,7 @@ class TQLabel;
class TQPopupMenu;
class XkbRules;
/* This class is responsible for displaying flag/label for the layout,
catching keyboard/mouse events and displaying menu when selected
*/
@@ -37,10 +37,10 @@ public:
KxkbLabelController(TQLabel *label, TQPopupMenu* contextMenu);
- void initLayoutList(const TQValueList<LayoutUnit>& layouts, const XkbRules& rule);
- void setCurrentLayout(const LayoutUnit& layout);
-// void setCurrentLayout(const TQString& layout, const TQString &variant);
- void setError(const TQString& layoutInfo="");
+ void initLayoutList(const TQValueList<LayoutUnit>& tqlayouts, const XkbRules& rule);
+ void setCurrentLayout(const LayoutUnit& tqlayout);
+// void setCurrentLayout(const TQString& tqlayout, const TQString &variant);
+ void setError(const TQString& tqlayoutInfo="");
void setShowFlag(bool showFlag) { m_showFlag = showFlag; }
void show() { label->show(); }
@@ -24,7 +24,7 @@ class TQLabel;
class TQPopupMenu;
class XkbRules;
-/* This class is responsible for displaying flag/label for the layout,
+/* This class is responsible for displaying flag/label for the tqlayout,
catching keyboard/mouse events and displaying menu when selected
*/